4Suite API Documentation: Ft.Lib.DistExt.InstallLib

4Suite™ API Documentation

# ► Module Ft.Lib.DistExt.InstallLib

Classes: InstallLib |  |  |  | Globals: PY_SOURCE_EXTS, m, s, t

## Classes

class InstallLib(distutils.command.install_lib.install_lib)

  ### Methods

  get_source_files(self)
  install(self)
    Overrides: install from class install_lib

  ### Methods inherited from class distutils.command.install_lib.install_lib

  build, byte_compile, finalize_options, get_inputs, get_outputs, initialize_options, run

  ### Methods inherited from class distutils.cmd.Command

  __getattr__, __init__, announce, copy_file, copy_tree, debug_print, dump_options, ensure_dirname, ensure_filename, ensure_finalized, ensure_string, ensure_string_list, execute, get_command_name, get_finalized_command, get_sub_commands, make_archive, make_file, mkpath, move_file, reinitialize_command, run_command, set_undefined_options, spawn, warn

  ### Members

  boolean_options = ['force', 'compile', 'skip-build']
  command_name = 'install_lib'
  negative_opt = {'no-compile': 'compile'}
  user_options = [('force', 'f', 'force installation (overwrite existing files)'), ('compile', 'c', 'compile .py to .pyc [default]'), ('no-compile', None, "don't compile .py files"), ('optimize=', 'O', 'also compile with optimization: -O1 for "python ...r "python -OO", and -O0 to disable [default: -O0]'), ('skip-build', None, 'skip the build steps')]

  ### Members inherited from class distutils.command.install_lib.install_lib

  description

  ### Members inherited from class distutils.cmd.Command

  sub_commands

## Globals

PY_SOURCE_EXTS = ['.py']
m = 'rb'
s = '.pyc'
t = 2